@@ -45,6 +45,7 @@ class Tinebase_Application
     const STATE_FILESYSTEM_ROOT_REVISION_SIZE = 'filesystemRootRevisionSize';
     const STATE_FILESYSTEM_ROOT_SIZE = 'filesystemRootSize';
     const STATE_REPLICATION_MASTER_ID = 'replicationMasterId';
+    const STATE_REPLICATION_PRIMARY_TB_ID = 'replicationPrimaryTBId';
     const STATE_UPDATES = 'updates';
 
 
@@ -320,6 +321,7 @@ class Tinebase_Application
      */
     public function setApplicationStatus($_applicationIds, $state)
     {
+        $state = strtolower($state);
         if (!in_array($state, array(Tinebase_Application::ENABLED, Tinebase_Application::DISABLED))) {
             throw new Tinebase_Exception_InvalidArgument('$_state can be only Tinebase_Application::DISABLED  or Tinebase_Application::ENABLED');
         }
