@@ -43,6 +43,13 @@ class Crm_Config extends Tinebase_Config_Abstract
      */
     const FEATURE_LEAD_IMPORT = 'featureLeadImport';
 
+    /**
+     * lead notification confirmation
+     *
+     * @var string
+     */
+    const FEATURE_LEAD_NOTIFICATION_CONFIRMATION = 'featureLeadNotificationConfirmation';
+
     /**
      * lead import auto task
      *
@@ -71,6 +78,7 @@ class Crm_Config extends Tinebase_Config_Abstract
     const SEND_NOTIFICATION_TO_RESPONSIBLE = 'sendnotificationtoresponsible';
     const SEND_NOTIFICATION_TO_CUSTOMER = 'sendnotificationtocustomer';
     const SEND_NOTIFICATION_TO_PARTNER = 'sendnotificationtopartner';
+    const SEND_NOTIFICATION_TO_ALL_ACCESS = 'sendnotificationtoallaccess';
 
 
     /**
@@ -86,6 +94,14 @@ class Crm_Config extends Tinebase_Config_Abstract
             'setByAdminModule' => true,
             'clientRegistryInclude' => TRUE,
         ),
+        self::SEND_NOTIFICATION_TO_ALL_ACCESS => array(
+            'label' => 'send notification to all access container', //_('send notification to all access container')
+            'description' => 'controls sending notification of Leads', //_('controls sending notification of Leads')
+            'type' => Tinebase_Config_Abstract::TYPE_BOOL,
+            'default' => true,
+            'setByAdminModule' => true,
+            'clientRegistryInclude' => TRUE,
+        ),
         self::SEND_NOTIFICATION_TO_RESPONSIBLE => array(
             'label' => 'send notification to responsible', //_('send notification to responsible'')
             'description' => 'send notification to responsible', //_('send notification to responsible')
@@ -190,6 +206,12 @@ class Crm_Config extends Tinebase_Config_Abstract
                     self::TYPE          => self::TYPE_BOOL,
                     self::DEFAULT_STR   => true,
                 ],
+                self::FEATURE_LEAD_NOTIFICATION_CONFIRMATION   => [
+                    self::LABEL         => 'Lead Notification Confirmation', //_('Lead Notification Confirmation')
+                    self::DESCRIPTION   => 'Lead Notification Confirmation',
+                    self::TYPE          => self::TYPE_BOOL,
+                    self::DEFAULT_STR   => false,
+                ],
             ],
             self::DEFAULT_STR => [],
         ],
