@@ -203,6 +203,11 @@ class Calendar_Config extends Tinebase_Config_Abstract
      */
     const FEATURE_RECUR_EXCEPT = 'featureRecurExcept';
 
+    /**
+     * @var string
+     */
+    const FEATURE_EVENT_NOTIFICATION_CONFIRMATION = 'featureEventNotificationConfirmation';
+
     /**
      * @var string
      */
@@ -394,8 +399,8 @@ class Calendar_Config extends Tinebase_Config_Abstract
             'setByAdminModule'      => TRUE,
             'default'               => array(
                 'records' => array(
-                    array('id' => 'REQ', 'value' => 'Required', 'system' => true, 'order' => 0), //_('Required')
-                    array('id' => 'OPT', 'value' => 'Optional', 'system' => true, 'order' => 1), //_('Optional')
+                    array('id' => 'REQ', 'value' => 'Required', 'system' => true, 'order' => 0, 'color' => '#FF0000'), //_('Required')
+                    array('id' => 'OPT', 'value' => 'Optional', 'system' => true, 'order' => 1, 'color' => '#0000FF'), //_('Optional')
                 ),
                 'default' => 'REQ'
             )
@@ -591,6 +596,12 @@ class Calendar_Config extends Tinebase_Config_Abstract
                     self::TYPE              => self::TYPE_BOOL,
                     self::DEFAULT_STR       => true,
                 ),
+                self::FEATURE_EVENT_NOTIFICATION_CONFIRMATION   => [
+                    self::LABEL         => 'Event Notification Confirmation', //_('Lead Notification Confirmation')
+                    self::DESCRIPTION   => 'Event Notification Confirmation',
+                    self::TYPE          => self::TYPE_BOOL,
+                    self::DEFAULT_STR   => false,
+                ],
             ],
             self::DEFAULT_STR => [],
         ],
