@@ -6,7 +6,7 @@
  * @subpackage  Controller
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Philipp Schüle <p.schuele@metaways.de>
- * @copyright   Copyright (c) 2009-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2009-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 /**
@@ -317,7 +317,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         Felamimail_Controller_Account::getInstance()->addSystemAccountConfigValues($_record);
 
         $user = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($_record);
-        $this->_checkIfEmailUserExists($user);
+        Tinebase_EmailUser::checkIfEmailUserExists($user);
 
         $emailUserBackend->inspectAddUser($user, $user);
         Tinebase_EmailUser::getInstance(Tinebase_Config::SMTP)->inspectAddUser($user, $user);
@@ -552,14 +552,6 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         }
     }
 
-    protected function _checkIfEmailUserExists($user)
-    {
-        $emailUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::SMTP);
-        if ($emailUserBackend->emailAddressExists($user)) {
-            throw new Tinebase_Exception_SystemGeneric('email account already exists');
-        }
-    }
-    
     /**
      * inspect update of one record
      * 
@@ -613,7 +605,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         if ($_oldRecord->email !== $_record->email) {
             // check only with email address!
             $user = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($_record, [], false);
-            $this->_checkIfEmailUserExists($user);
+            Tinebase_EmailUser::checkIfEmailUserExists($user);
             Tinebase_EmailUser_XpropsFacade::updateEmailUsers($_record);
         }
 
@@ -758,7 +750,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
     /**
      * @param $_record
      * @param $_oldRecord
-     * @throws Tinebase_Exception_UnexpectedValue
+     * @throws Tinebase_Exception_SystemGeneric
      */
     protected function _convertToUserInternal($_record, $_oldRecord)
     {
@@ -768,7 +760,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
 
         if (! $_record->user_id) {
             $translation = Tinebase_Translation::getTranslation('Felamimail');
-            throw new Tinebase_Exception_UnexpectedValue($translation->_('userInternal accounts need to have an user_id set'));
+            throw new Tinebase_Exception_SystemGeneric($translation->_('Internal user accounts need a valid user'));
         }
 
         $this->_transferEmailUserIdXprops($_record, $_oldRecord);
@@ -778,7 +770,7 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             $systemEmailUser = $this->_getEmailSystemUser($_record->user_id);
             if (! $systemEmailUser->getId()) {
                 $translation = Tinebase_Translation::getTranslation('Felamimail');
-                throw new Tinebase_Exception_UnexpectedValue($translation->_('System account of user is missing'));
+                throw new Tinebase_Exception_SystemGeneric($translation->_('System account of user is missing'));
             }
             $emailUser = Tinebase_EmailUser_XpropsFacade::getEmailUserFromRecord($_record);
             $emailUserBackend = Tinebase_EmailUser::getInstance(Tinebase_Config::IMAP);
@@ -826,6 +818,8 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             'drafts_folder',
             'templates_folder',
             'migration_approved',
+            'from',
+            'organization',
         );
         $diff = $_record->diff($_oldRecord)->diff;
         foreach ($diff as $key => $value) {
@@ -920,21 +914,24 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             $newUsername = ($_record->user) ? $_record->user : $credentials->username;
 
             $_record->credentials_id = $this->_createSharedCredentials($newUsername, $newPassword);
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                __METHOD__ . '::' . __LINE__ . ' Created new credentials (id ' . $_record->credentials_id . ')');
+
             $imapCredentialsChanged = true;
         } else {
+            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                    __METHOD__ . '::' . __LINE__ . ' Credentials did not change');
             $imapCredentialsChanged = false;
         }
 
         if ($_record->smtp_user && $_record->smtp_password) {
+            // NOTE: this is currently not possible to set via the FE - maybe we should remove it?
             // create extra smtp credentials
             if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
                 __METHOD__ . '::' . __LINE__ . ' Update/create SMTP credentials.');
             $_record->smtp_credentials_id = $this->_createSharedCredentials($_record->smtp_user, $_record->smtp_password);
 
-        } else if (
-            $imapCredentialsChanged
-            && (! $_record->smtp_credentials_id || $_record->smtp_credentials_id == $_oldRecord->credentials_id)
-        ) {
+        } else if ($imapCredentialsChanged) {
             // use imap credentials for smtp auth as well
             $_record->smtp_credentials_id = $_record->credentials_id;
         }
@@ -1911,14 +1908,19 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
         if (empty($_account->name) && $_account->type !== Felamimail_Model_Account::TYPE_USER_INTERNAL) {
             $_account->name = $_email;
         }
-        $_account->from = $_user->accountFullName;
-        
+        if (empty($_account->from)) {
+            $_account->from = $_user->accountFullName;
+        }
+
         // add contact data (if available)
         try {
             $contact = Addressbook_Controller_Contact::getInstance()->getContactByUserId($_user->getId(), TRUE);
-            $_account->organization = $contact->org_name;
+            if (empty($_account->organization)) {
+                $_account->organization = $contact->org_name;
+            }
         } catch (Addressbook_Exception_NotFound $aenf) {
-            Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' Could not get system account user contact: ' . $aenf->getMessage());
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
+                . ' Could not get system account user contact: ' . $aenf->getMessage());
         }
     }
 
@@ -1933,10 +1935,14 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
      */
     public function getMultiple($_ids, $_ignoreACL = false, Tinebase_Record_Expander $_expander = null, $_getDeleted = false)
     {
-        // TODO fix me! system account resolving is mssing, add it here?!
+        // TODO fix me! system account resolving is missing, add it here?!
         throw new Tinebase_Exception_NotImplemented('do not use this function');
     }
 
+    /**
+     * @param Addressbook_Model_List $list
+     * @return false|Tinebase_Record_Interface
+     */
     public function getAccountForList(Addressbook_Model_List $list)
     {
         $account = Felamimail_Controller_Account::getInstance()->search(
@@ -1946,8 +1952,8 @@ class Felamimail_Controller_Account extends Tinebase_Controller_Record_Grants
             ]))->getFirstRecord();
 
         if (null === $account) {
-            $e = new Tinebase_Exception('no felamimail account found for list ' . $list->getId());
-            Tinebase_Exception::log($e);
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
+                . ' No felamimail account found for list ' . $list->getId());
             return false;
         }
 
