@@ -6,7 +6,7 @@
  * @subpackage  Controller
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Philipp Schüle <p.schuele@metaways.de>
- * @copyright   Copyright (c) 2009-2018 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2009-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 /**
@@ -768,6 +768,8 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
             
             try {
                 $messages = $_imap->getSummary($messageSequenceStart, $messageSequenceEnd, false);
+
+
             } catch (Zend_Mail_Protocol_Exception $zmpe) {
                 // imap server might have gone away during update
                 Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ 
@@ -801,6 +803,12 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
                 .  ' ' . print_r($message, TRUE));
 
             $transactionId = Tinebase_TransactionManager::getInstance()->startTransaction(Tinebase_Core::getDb());
+
+            if (array_key_exists('header', $message) && array_key_exists('received', $message['header'])) {
+                $received = explode(';', $message['header']['received'][0]);
+                $message['received'] = isset($received[1]) ? date("d-M-Y H:i:s O", strtotime($received[1])) : $message['received'];
+            }
+            
             try {
                 if ($this->addMessage($message, $_folder)) {
                     $_folder->cache_job_actions_done++;
@@ -889,11 +897,18 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
     public function addMessage(array $_message, Felamimail_Model_Folder $_folder, $_updateFolderCounter = true)
     {
         if (! (isset($_message['header']) || array_key_exists('header', $_message)) || ! is_array($_message['header'])) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__ . ' Email uid ' . $_message['uid'] . ' has no headers. Skipping ...');
+            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(
+                __METHOD__ . '::' . __LINE__ . ' Email uid ' . $_message['uid'] . ' has no headers. Skipping ...');
             return false;
         }
         
         $messageToCache = $this->_createMessageToCache($_message, $_folder);
+        
+        if (Felamimail_Config::getInstance()->featureEnabled(Felamimail_Config::FEATURE_SPAM_SUSPICION_STRATEGY)) {
+            $strategy = Felamimail_Spam_SuspicionStrategy_Factory::factory();
+            $messageToCache->is_spam_suspicions = $strategy->apply($messageToCache);
+        }
+        
         $cachedMessage = $this->addMessageToCache($messageToCache);
 
         if ($cachedMessage !== false) {
@@ -939,7 +954,12 @@ class Felamimail_Controller_Cache_Message extends Felamimail_Controller_Message
         
         $attachments = $this->getAttachments($message);
         $message->has_attachment = (count($attachments) > 0) ? true : false;
-        
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+            __METHOD__ . '::' . __LINE__ . ' Adding message to cache: ' . print_r($message->toArray(), true));
+        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(
+            __METHOD__ . '::' . __LINE__ . ' Raw data: ' . print_r($_message, true));
+
         return $message;
     }
 
