@@ -98,7 +98,7 @@ class Sales_Controller_Contract extends Sales_Controller_NumberableAbstract
     public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = TRUE)
      {
         if ($_duplicateCheck) {
-            $this->_checkNumberUniquity($_record, true);
+            $this->_checkNumberUniqueness($_record, true);
         }
         $this->_checkNumberType($_record);
         return parent::update($_record, $_duplicateCheck);
@@ -122,7 +122,7 @@ class Sales_Controller_Contract extends Sales_Controller_NumberableAbstract
             $this->_addNextNumber($_record);
         } else {
             // check uniquity if not autogenerated
-            $this->_checkNumberUniquity($_record, false);
+            $this->_checkNumberUniqueness($_record, false);
         }
         
         // check type
