@@ -47,13 +47,6 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
      */
     protected $_backend = NULL;
 
-    /**
-     * punycode converter
-     *
-     * @var idna_convert
-     */
-    protected $_punycodeConverter = NULL;
-
     /**
      * foreign application content types
      *
@@ -143,6 +136,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
      * @param string $mimeType
      * @param boolean $_setSeen
      * @return Felamimail_Model_Message
+     * @throws Exception
      */
     public function getCompleteMessage($_id, $_partId = NULL, $mimeType = 'configured', $_setSeen = FALSE)
     {
@@ -167,6 +161,11 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
             Felamimail_Controller_Message_Flags::getInstance()->setTine20Flag($message);
         }
 
+        if (Felamimail_Config::getInstance()->featureEnabled(Felamimail_Config::FEATURE_SPAM_SUSPICION_STRATEGY)) {
+            $strategy = Felamimail_Spam_SuspicionStrategy_Factory::factory();
+            $message->is_spam_suspicions = $strategy->apply($message);
+        }
+
         if ($_setSeen) {
             Felamimail_Controller_Message_Flags::getInstance()->setSeenFlag($message);
         }
@@ -227,7 +226,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
             $_message->has_attachment = true;
         }
 
-        $attachments = array_merge($attachments, $this->getAttachments($_message, $_partId));
+        $attachments = array_merge($attachments, $this->getAttachments($_message, $_partId, true));
 
         if ($_partId === null) {
             $message = $_message;
@@ -533,13 +532,11 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         // remove possible harmful utf-8 chars
         // TODO should not be enabled by default (configurable?)
         $subjectAndMail = Tinebase_Helper::mbConvertTo($message->from_email . '_' . $subject, 'ASCII');
-        $name = str_replace(' ', '_', $message->received->toString('Y-m-d'))
+        return str_replace(' ', '_', $message->received->toString('Y-m-d'))
             . '_' . mb_substr($subjectAndMail, 0, 245)
             . '_' . mb_substr(md5($message->messageuid
             . $message->folder_id), 0, 10)
             . '.eml';
-
-        return $name;
     }
 
     /**
@@ -1008,9 +1005,11 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
      * get attachments of message
      *
      * @param array $_structure
+     * @param string $_partId
+     * @param boolean $_skipEmptyAttachments
      * @return array
      */
-    public function getAttachments($_messageId, $_partId = null)
+    public function getAttachments($_messageId, $_partId = null, $_skipEmptyAttachments = false)
     {
         if (!$_messageId instanceof Felamimail_Model_Message) {
             $message = $this->_backend->get($_messageId);
@@ -1070,6 +1069,10 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
 
                         if (!empty($expanded)) {
                             $attachments = array_merge($attachments, $expanded);
+                        } else if ($_skipEmptyAttachments) {
+                            if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
+                                . ' Skipping empty winmail.dat attachment.');
+                            continue;
                         }
                     }
                 }
@@ -1292,22 +1295,6 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         return Felamimail_Controller_Folder::getInstance()->getMultiple(array_keys($_folderCounter));
     }
 
-    /**
-     * get punycode converter
-     *
-     * @return NULL|idna_convert
-     */
-    public function getPunycodeConverter()
-    {
-        if ($this->_punycodeConverter === NULL) {
-            if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
-                . ' Creating idna convert class for punycode conversion.');
-            $this->_punycodeConverter = new idna_convert();
-        }
-
-        return $this->_punycodeConverter;
-    }
-
     /**
      * get resource part id
      *
@@ -1431,8 +1418,7 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         }
 
         // save draft in draft folder
-        $draft = Felamimail_Controller_Message_Send::getInstance()->saveMessageInFolder($draftFolder, $_message, [Zend_Mail_Storage::FLAG_SEEN]);
-        return $draft;
+        return Felamimail_Controller_Message_Send::getInstance()->saveMessageInFolder($draftFolder, $_message, [Zend_Mail_Storage::FLAG_SEEN]);
     }
 
     /**
@@ -1504,4 +1490,101 @@ class Felamimail_Controller_Message extends Tinebase_Controller_Record_Abstract
         ]));
         return $result->getFirstRecord();
     }
+
+    /**
+     * @param Felamimail_Model_Message $message
+     * @param $newSubject
+     * @return Felamimail_Model_Message
+     * @throws Felamimail_Exception_IMAP
+     */
+    public function rewriteMessageSubject(Felamimail_Model_Message $message, $newSubject)
+    {
+        $folder = Felamimail_Controller_Folder::getInstance()->get($message->folder_id);
+        $account = Felamimail_Controller_Account::getInstance()->get($message->account_id);
+
+        $updatedMessage = clone($message);
+        $updatedMessage->subject = $newSubject;
+        $imap = Felamimail_Backend_ImapFactory::factory($account);
+        $mailToAppend = Felamimail_Controller_Message_Send::getInstance()->createMailForSending(
+            $updatedMessage,
+            $account,
+            $_nonPrivateRecipients,
+            true
+        );
+        $transport = new Felamimail_Transport();
+        $mailAsString = $transport->getRawMessage($mailToAppend);
+        $uid = $imap->appendMessage(
+            $mailAsString,
+            Felamimail_Model_Folder::encodeFolderName($folder->globalname),
+            []
+        );
+
+        if ($uid) {
+            $updatedMessage->messageuid = $uid;
+        } else {
+            throw new Felamimail_Exception_IMAP('appendMessage failed');
+        }
+
+        // remove old message
+        if ($message->messageuid) {
+            $imap->addFlags([$message->messageuid], [Zend_Mail_Storage::FLAG_DELETED]);
+        }
+
+        return $updatedMessage;
+    }
+
+    /**
+     * copy message with
+     * @param Felamimail_Model_Message $message
+     * @param $wrapTo
+     * @param $targetFolder
+     * @return Felamimail_Model_Message
+     * @throws Felamimail_Exception
+     * @throws Felamimail_Exception_IMAP
+     * @throws Felamimail_Exception_IMAPInvalidCredentials
+     * @throws Tinebase_Exception_Record_DefinitionFailure
+     * @throws Tinebase_Exception_Record_Validation
+     * @throws Zend_Mail_Transport_Exception
+     */
+    public function copyMessageWithAttachment(Felamimail_Model_Message $message, $wrapTo, $targetFolder)
+    {
+        $account = Felamimail_Controller_Account::getInstance()->get($message->account_id);
+
+        $updatedMessage = clone($message);
+        $updatedMessage->subject = $wrapTo['subject'];
+        $updatedMessage->to = $wrapTo['to'];
+        $updatedMessage->original_id = $message->getId(); // doesnt work
+        $updatedMessage->attachments =  [new Tinebase_Model_TempFile([
+            'type'  => Felamimail_Model_Message::CONTENT_TYPE_MESSAGE_RFC822,
+            'name'  => $message->subject,
+        ], TRUE)];
+
+        $imap = Felamimail_Backend_ImapFactory::factory($account);
+        $mailToAppend = Felamimail_Controller_Message_Send::getInstance()->createMailForSending(
+            $updatedMessage,
+            $account,
+            $_nonPrivateRecipients,
+            true
+        );
+        $transport = new Felamimail_Transport();
+        $mailAsString = $transport->getRawMessage($mailToAppend);
+        $uid = $imap->appendMessage(
+            $mailAsString,
+            Felamimail_Model_Folder::encodeFolderName($targetFolder->globalname),
+            []
+        );
+
+        if ($uid) {
+            $updatedMessage->messageuid = $uid;
+        } else {
+            throw new Felamimail_Exception_IMAP('appendMessage failed');
+        }
+
+        // remove old message
+        if ($message->messageuid) {
+            $imap->addFlags([$message->messageuid], [Zend_Mail_Storage::FLAG_DELETED]);
+        }
+        
+        return $updatedMessage;
+    }
 }
