@@ -6,7 +6,7 @@
  * @subpackage  Controller
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Philipp Schüle <p.schuele@metaways.de>
- * @copyright   Copyright (c) 2011-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2011-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  * 
  * @todo        add transactions to move/create/delete/copy 
  */
@@ -63,6 +63,11 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
      * @var bool
      */
     protected $_throwOnGetQuarantined = true;
+
+    protected $_createNodeInBackendInterceptor = [];
+    protected $_moveNodesHook = [];
+
+    protected $_allowedProperties = ['name', 'description', 'relations', 'customfields', 'tags', 'notes', 'acl_node', 'grants', 'quota', Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION, Tinebase_Model_Tree_Node::XPROPS_REVISION, 'pin_protected_node'];
     
     /**
      * holds the instance of the singleton
@@ -104,6 +109,12 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         return self::$_instance;
     }
 
+    public function addAllowedProperty($property) {
+        if (!in_array($property, $this->_allowedProperties)) {
+            $this->_allowedProperties[] = $property;
+        }
+    }
+
     /**
      * get/set whether to throw on access on quarantined file
      *
@@ -120,8 +131,15 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
     }
 
     /**
-     * (non-PHPdoc)
-     * @see Tinebase_Controller_Record_Abstract::update()
+     * @param Tinebase_Record_Interface $_record
+     * @param bool $_duplicateCheck
+     * @return Tinebase_Record_Interface
+     * @throws Tinebase_Exception_AccessDenied
+     *
+     * @refactor should be improved:
+     *   1) move notification update stuff to separate function
+     *   2) remove code duplication (xprops loops)
+     *   3) find out, why xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION) does not return an array in some cases
      */
     public function update(Tinebase_Record_Interface $_record, $_duplicateCheck = true)
     {
@@ -135,13 +153,15 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
 
             $usersNotificationSettings = null;
             $currentUserId = Tinebase_Core::getUser()->getId();
-            foreach ($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION) as $xpNotification) {
-                if (isset($xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) &&
+            if (is_array($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION))) {
+                foreach ($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION) as $xpNotification) {
+                    if (isset($xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) &&
                         isset($xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_TYPE]) &&
                         Tinebase_Acl_Rights::ACCOUNT_TYPE_USER === $xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_TYPE] &&
-                        $currentUserId ===  $xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) {
-                    $usersNotificationSettings = $xpNotification;
-                    break;
+                        $currentUserId === $xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) {
+                        $usersNotificationSettings = $xpNotification;
+                        break;
+                    }
                 }
             }
 
@@ -158,20 +178,23 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
             }
 
             $found = false;
-            foreach ($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION) as $key => &$xpNotification) {
-                if (isset($xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) &&
+            if (is_array($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION))) {
+                foreach ($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION) as $key => &$xpNotification) {
+                    if (isset($xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) &&
                         isset($xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_TYPE]) &&
                         Tinebase_Acl_Rights::ACCOUNT_TYPE_USER === $xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_TYPE] &&
-                        $currentUserId ===  $xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) {
-                    if (null !== $usersNotificationSettings) {
-                        $xpNotification = $usersNotificationSettings;
-                    } else {
-                        unset($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION)[$key]);
+                        $currentUserId === $xpNotification[Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION_ACCOUNT_ID]) {
+                        if (null !== $usersNotificationSettings) {
+                            $xpNotification = $usersNotificationSettings;
+                        } else {
+                            unset($_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION)[$key]);
+                        }
+                        $found = true;
+                        break;
                     }
-                    $found = true;
-                    break;
                 }
             }
+
             if (false === $found && null !== $usersNotificationSettings) {
                 $_record->xprops(Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION)[] = $usersNotificationSettings;
             }
@@ -183,7 +206,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
 
         return parent::update($_record, $_duplicateCheck);
     }
-    
+
     /**
      * inspect update of one record (before update)
      *
@@ -195,7 +218,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
     {
         // protect against file object spoofing
         foreach (array_keys($_record->toArray()) as $property) {
-            if (! in_array($property, array('name', 'description', 'relations', 'customfields', 'tags', 'notes', 'acl_node', 'grants', 'quota', Tinebase_Model_Tree_Node::XPROPS_NOTIFICATION, Tinebase_Model_Tree_Node::XPROPS_REVISION, 'pin_protected_node'))) {
+            if (! in_array($property, $this->_allowedProperties)) {
                 $_record->{$property} = $_oldRecord->{$property};
             }
         }
@@ -448,7 +471,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
     protected function _searchNodesRecursive($_filter, $_pagination)
     {
         $_filter->removeFilter('type');
-        $_filter->addFilter($_filter->createFilter('type', 'equals', Tinebase_Model_Tree_FileObject::TYPE_FILE));
+        $_filter->addFilter($_filter->createFilter('type', 'in', [Tinebase_Model_Tree_FileObject::TYPE_FILE, Tinebase_Model_Tree_FileObject::TYPE_LINK]));
         $filter = clone $_filter;
         // prepend base path to original $_filter object! it is required for toArray() in the response array
         $this->_ensurePathFilterPresent($_filter);
@@ -498,7 +521,33 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         
         return $result;
     }
-    
+
+    /**
+     * @param Tinebase_Model_Tree_Node $_child
+     * @param Tinebase_Model_Tree_Node_Filter $_filter
+     * @return Tinebase_Model_Tree_Node
+     * @throws Tinebase_Exception_InvalidArgument
+     * @throws Tinebase_Exception_NotFound
+     */
+    public function getParentByFilter(Tinebase_Model_Tree_Node $_child, Tinebase_Model_Tree_Node_Filter $_filter)
+    {
+        if (null === ($parent = $this->_backend->getParentByFilter($_child, $_filter))) {
+            throw new Tinebase_Exception_NotFound('no parent matching given filter found');
+        }
+        $parentPath = Tinebase_Model_Tree_Node_Path::createFromStatPath($this->_backend->getPathOfNode($parent, true));
+
+        $app = Tinebase_Application::getInstance()->getApplicationByName($this->_applicationName);
+        $appPath = '/' . $app->getId() . '/' . Tinebase_Model_Tree_Node_Path::FOLDERS_PART;
+
+        if (strpos($parentPath->statpath, $appPath) !== 0) {
+            throw new Tinebase_Exception_NotFound('no parent matching given filter found');
+        }
+        $this->_backend->checkPathACL($parentPath, 'get');
+        $parent->path = substr($parentPath->statpath, strlen($appPath));
+
+        return $parent;
+    }
+
     /**
      * checks filter acl and adds base path
      * 
@@ -632,13 +681,16 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
      * @param Tinebase_Model_Tree_Node_Path $_path
      * @param integer|null $_revision
      * @return Tinebase_Model_Tree_Node
+     * @throws Tinebase_Exception_NotFound
+     * @throws Filemanager_Exception
+     * @throws Filemanager_Exception_Quarantined
      */
     public function getFileNode(Tinebase_Model_Tree_Node_Path $_path, $_revision = null)
     {
         $this->_backend->checkPathACL($_path, 'get');
         
         if (! $this->_backend->fileExists($_path->statpath, $_revision)) {
-            throw new Filemanager_Exception('File does not exist,');
+            throw new Tinebase_Exception_NotFound('File does not exist,');
         }
         
         if (! $this->_backend->isFile($_path->statpath)) {
@@ -701,7 +753,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
             $filter->removeFilter('path');
             $filter->removeFilter('recursive');
             $filter->removeFilter('type');
-            $filter->addFilter($filter->createFilter('type', 'equals', Tinebase_Model_Tree_FileObject::TYPE_FILE));
+            $filter->addFilter($filter->createFilter('type', 'in', [Tinebase_Model_Tree_FileObject::TYPE_FILE, Tinebase_Model_Tree_FileObject::TYPE_LINK]));
             $filter = new Tinebase_Model_Tree_Node_Filter($filter->toArray(), '', array('nameCaseInSensitive' => true));
             $result = $this->_backend->searchNodesCount($filter);
         } else {
@@ -861,7 +913,17 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         $this->resolveGrants($newNode);
         return $newNode;
     }
-    
+
+    public function registerCreateNodeInBackendInterceptor($key, $callable)
+    {
+        $this->_createNodeInBackendInterceptor[$key] = $callable;
+    }
+
+    public function registerMoveNodesHook($key, $callable)
+    {
+        $this->_moveNodesHook[$key] = $callable;
+    }
+
     /**
      * create node in backend
      * 
@@ -876,7 +938,12 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
         if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ . 
             ' Creating new path ' . $_statpath . ' of type ' . $_type);
 
-        $node = NULL;
+        $node = null;
+        foreach ($this->_createNodeInBackendInterceptor as $callable) {
+            if (null !== ($node = call_user_func($callable, $_statpath, $_type, $_tempFileId))) {
+                return $node;
+            }
+        }
         switch ($_type) {
             case Tinebase_Model_Tree_FileObject::TYPE_FOLDER:
                 $path = Tinebase_Model_Tree_Node_Path::createFromStatPath($_statpath);
@@ -892,7 +959,7 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
                     $_type = null;
                 }
                 if (! $_tempFileId) {
-                    $this->_backend->createFileTreeNode($this->_backend->stat(dirname($_statpath)),
+                    $node = $this->_backend->createFileTreeNode($this->_backend->stat(dirname($_statpath)),
                         basename($_statpath), Tinebase_Model_Tree_FileObject::TYPE_FILE, $_type);
                 } else {
                     try {
@@ -1302,6 +1369,14 @@ class Filemanager_Controller_Node extends Tinebase_Controller_Record_Abstract
      */
     public function moveNodes($_sourceFilenames, $_destinationFilenames, $_forceOverwrite = FALSE)
     {
+        // yeah, really...
+        new Filemanager_Model_Node([], true);
+        // we need to save the result of the hook, it might be a scoped object that gets destructed at the end of scope
+        $hookResult = [];
+        foreach ($this->_moveNodesHook as $hook) {
+            $hookResult[] = call_user_func($hook);
+        }
+        
         return $this->_copyOrMoveNodes($_sourceFilenames, $_destinationFilenames, 'move', $_forceOverwrite);
     }
     
