@@ -407,7 +407,7 @@ class Tinebase_Core
 
         $controllerName = $appNameString;
         if ($appName !== 'Tinebase' || ($appName === 'Tinebase' && ! $modelName)) {
-            // only app controllers are called "App_Controller_Model"
+            // app controllers are called "App_Controller_Model", most Tinebase controllers are just "Tinebase_Model"
             $controllerName .= '_Controller';
         }
         
@@ -421,10 +421,13 @@ class Tinebase_Core
             $modelName = preg_replace('/^' . $appName . '_' . 'Model_/', '', $modelName);
             $controllerNameModel = $controllerName . '_' . $modelName;
             if (! class_exists($controllerNameModel)) {
-                throw new Tinebase_Exception_NotFound('No Application Controller found (checked class ' . $controllerNameModel . ')!');
-            } else {
-                $controllerName = $controllerNameModel;
+                $controllerNameModel = $controllerName . '_Controller_' . $modelName;
+                if (! class_exists($controllerNameModel)) {
+                    throw new Tinebase_Exception_NotFound('No Application Controller found (checked classes '
+                        . $controllerName . '_' . $modelName . ' and ' . $controllerNameModel . ')!');
+                }
             }
+            $controllerName = $controllerNameModel;
         } else if (! class_exists($controllerName)) {
             if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
                 . ' Use generic application controller');
@@ -498,15 +501,31 @@ class Tinebase_Core
         Tinebase_Core::setupDbLogger();
     }
 
+    /**
+     * setup the database logger
+     *
+     * @throws Tinebase_Exception_NotFound
+     * @throws Zend_Log_Exception
+     */
     protected static function setupDbLogger()
     {
         $config = self::getConfig();
         
-        if ($config->dblogger) {
+        if ($config->dblogger && $config->dblogger->active) {
             $logger = Tinebase_Core::getLogger();
-            $writer = $logger->getWriter($config->dblogger);
-            $writer->setFormatter($logger->getFormatter($config->dblogger));
-            $logger->addWriter($writer);
+            $loggerConfig = new Zend_Config(
+                [
+                    'database' => true,
+                    'priority' => $config->dblogger->priority,
+                    'active' => true,
+                    'formatter' => 'db',
+                ]
+            );
+            $writer = $logger->getWriter($loggerConfig);
+            if ($writer) {
+                $writer->setFormatter($logger->getFormatter($loggerConfig));
+                $logger->addWriter($writer);
+            }
         }
     }
     
@@ -657,9 +676,9 @@ class Tinebase_Core
             $buildType = Tinebase_Core::detectBuildType();
         }
         define('TINE20_BUILDTYPE', $buildType);
-        define('TINE20_CODENAME',      '2020.03');
-        define('TINE20_PACKAGESTRING', '2020.03.4');
-        define('TINE20_RELEASETIME', '2020-07-16 13:00:10');
+        define('TINE20_CODENAME',      '2020.08');
+        define('TINE20_PACKAGESTRING', '2020.08.8');
+        define('TINE20_RELEASETIME', '2021-01-21 10:28:14');
     }
 
     /**
@@ -795,8 +814,8 @@ class Tinebase_Core
                 @mkdir($tmpdir, 0777, true);
             }
         }
-        
-        return $tmpdir;
+
+        return rtrim($tmpdir, DIRECTORY_SEPARATOR);
     }
     
     /**
@@ -1058,11 +1077,7 @@ class Tinebase_Core
         }
         
         $dbConfig = $config->database;
-        
-        if (!empty($dbConfig->password)) {
-            self::getLogger()->addReplacement($dbConfig->password);
-        }
-        
+
         if (! defined('SQL_TABLE_PREFIX')) {
             define('SQL_TABLE_PREFIX', $dbConfig->get('tableprefix') ? $dbConfig->get('tableprefix') : 'tine20_');
         }
@@ -1089,6 +1104,10 @@ class Tinebase_Core
      */
     public static function createAndConfigureDbAdapter($dbConfigArray, $dbBackend = NULL)
     {
+        if (!empty($dbConfigArray['password'])) {
+            self::getLogger()->addReplacement($dbConfigArray['password']);
+        }
+
         if ($dbBackend === NULL) {
             $constName = 'self::' . strtoupper($dbConfigArray['adapter']);
             if (empty($dbConfigArray['adapter']) || ! defined($constName)) {
@@ -1772,6 +1791,19 @@ class Tinebase_Core
         return self::isRegistered(self::DB);
     }
 
+    /**
+     * @param string $variable
+     * @param Zend_Db_Adapter_Abstract $db
+     * @return false|mixed|string
+     */
+    public static function getDbVariable($variable, Zend_Db_Adapter_Abstract $db = null)
+    {
+        if ($db === null) {
+            $db = self::getDb();
+        }
+        return $db->query('SHOW VARIABLES LIKE "' . $variable . '"')->fetchColumn(1);
+    }
+
     /**
      * get db name
      *
@@ -1838,11 +1870,12 @@ class Tinebase_Core
      * returns requested url part
      *
      * @param string $part
+     * @param boolean $useConfig Tinebase_Config::TINE20_URL (if set)
      * @return string
      */
-    public static function getUrl($part = self::GET_URL_FULL)
+    public static function getUrl($part = self::GET_URL_FULL, $useConfig = true)
     {
-        if (empty($url = Tinebase_Config::getInstance()->get(Tinebase_Config::TINE20_URL))) {
+        if (! $useConfig || empty($configUrl = Tinebase_Config::getInstance()->get(Tinebase_Config::TINE20_URL))) {
             if (empty($_SERVER['SERVER_NAME']) && empty($_SERVER['HTTP_HOST'])) {
                 if (Tinebase_Core::isLogLevel(Zend_Log::WARN)) Tinebase_Core::getLogger()->warn(__METHOD__ . '::' . __LINE__
                     . ' neither SERVER_NAME nor HTTP_HOST are set and tine20URL config is not set too!');
@@ -1856,9 +1889,9 @@ class Tinebase_Core
                 $protocol = $request->getScheme();
             }
         } else {
-            $protocol = parse_url($url, PHP_URL_SCHEME);
-            $hostname = parse_url($url, PHP_URL_HOST);
-            $pathname = rtrim(str_replace($protocol . '://' . $hostname, '', $url), '/');
+            $protocol = parse_url($configUrl, PHP_URL_SCHEME);
+            $hostname = parse_url($configUrl, PHP_URL_HOST);
+            $pathname = rtrim(str_replace($protocol . '://' . $hostname, '', $configUrl), '/');
         }
 
         switch ($part) {
@@ -2154,6 +2187,22 @@ class Tinebase_Core
         return Tinebase_FileSystem_Preview_ServiceFactory::getPreviewService();
     }
 
+    public static function getPrimaryTinebaseId()
+    {
+        if (! isset(self::$appInstanceCache['PrimaryTinebaseId'])) {
+            self::$appInstanceCache['PrimaryTinebaseId'] = Tinebase_Application::getInstance()->getApplicationState(
+                'Tinebase', Tinebase_Application::STATE_REPLICATION_PRIMARY_TB_ID);
+        }
+        return self::$appInstanceCache['PrimaryTinebaseId'];
+    }
+
+    public static function setPrimaryTinebaseId($id)
+    {
+        self::$appInstanceCache['PrimaryTinebaseId'] = $id;
+        Tinebase_Application::getInstance()->setApplicationState('Tinebase',
+            Tinebase_Application::STATE_REPLICATION_PRIMARY_TB_ID, $id);
+    }
+
     /**
      * returns the tinebase id
      *
@@ -2246,6 +2295,16 @@ class Tinebase_Core
     /**
      * @return bool
      */
+    public static function isReplica()
+    {
+        return static::isReplicationSlave();
+    }
+
+    /**
+     * @return bool
+     *
+     * @deprecated use isReplica
+     */
     public static function isReplicationSlave()
     {
         if (null !== static::$_isReplicationSlave) {
@@ -2269,6 +2328,15 @@ class Tinebase_Core
     /**
      * @return bool
      */
+    public static function isReplicationPrimary()
+    {
+        return static::isReplicationMaster();
+    }
+
+    /**
+     * @return bool
+     * @deprecated use isReplicationPrimary
+     */
     public static function isReplicationMaster()
     {
         if (null !== static::$_isReplicationMaster) {
