@@ -238,8 +238,15 @@ abstract class Tinebase_Export_AbstractDeprecated implements Tinebase_Record_Ite
      * @param string $_format
      * @return string
      */
-    public function getDownloadFilename($_appName, $_format)
+    public function getDownloadFilename($_appName = null, $_format = null)
     {
+        if (! $_appName) {
+            $_appName = $this->_applicationName;
+        }
+        if (! $_format) {
+            $_format = $this->_format;
+        }
+
         return 'export_' . strtolower($_appName) . '.' . $_format;
     }
 
@@ -386,6 +393,7 @@ abstract class Tinebase_Export_AbstractDeprecated implements Tinebase_Record_Ite
             $filter = Tinebase_Model_Filter_FilterGroup::getFilterForModel(Tinebase_Model_ImportExportDefinition::class, array(
                 array('field' => 'model', 'operator' => 'equals', 'value' => $this->_modelName),
                 array('field' => 'name',  'operator' => 'equals', 'value' => $exportName),
+                array('field' => 'type',  'operator' => 'equals', 'value' => 'export'),
             ));
             $definitions = Tinebase_ImportExportDefinition::getInstance()->search($filter);
             if (count($definitions) == 0) {
@@ -705,4 +713,42 @@ abstract class Tinebase_Export_AbstractDeprecated implements Tinebase_Record_Ite
         }
         return null;
     }
+
+    /**
+     * @return bool
+     *
+     * TODO remove code duplication with \Tinebase_Export_Abstract::isDownload
+     */
+    public function isDownload()
+    {
+        return !$this->_config->returnFileLocation;
+    }
+
+    /**
+     * @param null|string $filename
+     * @return Tinebase_Model_Tree_FileLocation
+     * @throws Tinebase_Exception_NotImplemented
+     *
+     * TODO remove code duplication with \Tinebase_Export_Abstract::getTargetFileLocation
+     */
+    public function getTargetFileLocation($filename = null)
+    {
+        if ($filename === null) {
+            if (method_exists($this, 'write')) {
+                ob_start();
+                $this->write();
+                $output = ob_get_clean();
+                $filename = Tinebase_TempFile::getTempPath();
+                file_put_contents($filename, $output);
+            } else {
+                throw new Tinebase_Exception_NotImplemented('Not implemented for this export');
+            }
+        }
+
+        $tempFile = Tinebase_TempFile::getInstance()->createTempFile($filename, $this->getDownloadFilename());
+        return new Tinebase_Model_Tree_FileLocation([
+            Tinebase_Model_Tree_FileLocation::FLD_TYPE => Tinebase_Model_Tree_FileLocation::TYPE_DOWNLOAD,
+            Tinebase_Model_Tree_FileLocation::FLD_TEMPFILE_ID => $tempFile->getId(),
+        ]);
+    }
 }
