@@ -151,6 +151,8 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
         $this->_currentProcessor = $this->_dataSources[$_name];
         $this->_currentDataSource = $_name;
         $this->_rowCount = 0;
+
+        $this->renderProcessorsTwigTemplate();
     }
 
     /**
@@ -212,6 +214,8 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
             $processor->setValue('${GROUP_BLOCK}', $this->_cutXml($this->_currentProcessor->getMainPart()));
             $this->_currentProcessor = $processor;
         }
+
+        $this->renderProcessorsTwigTemplate();
     }
 
     protected function _startGroup()
@@ -226,6 +230,8 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
             $this->_currentProcessor = $this->_currentProcessor->getConfig('group');
         }
 
+        $this->renderProcessorsTwigTemplate();
+
         if ($this->_currentProcessor->getType() === Tinebase_Export_Richtext_TemplateProcessor::TYPE_GROUP ||
                 $this->_currentProcessor->getType() === Tinebase_Export_Richtext_TemplateProcessor::TYPE_SUBGROUP) {
             if ($this->_rowCount > 0 && $this->_currentProcessor->hasConfig('groupSeparator')) {
@@ -289,12 +295,16 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
 
         $this->_rowCount += 1;
 
+        $this->renderProcessorsTwigTemplate();
+
         if ($this->_currentProcessor->hasConfig('recordRow')) {
             $recordRow = $this->_currentProcessor->getConfig('recordRow');
             $this->_currentProcessor->setValue('${RECORD_ROW}', $recordRow['recordRow'] . '${RECORD_ROW}');
         } else {
             if ($this->_currentProcessor->hasConfig('record')) {
                 $this->_currentProcessor = $this->_currentProcessor->getConfig('record');
+
+                $this->renderProcessorsTwigTemplate();
             }
 
             if ($this->_currentProcessor->getType() === Tinebase_Export_Richtext_TemplateProcessor::TYPE_RECORD ||
@@ -320,8 +330,6 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
                     }
                     $parent->setValue($name, $data);
                 }
-            } else {
-                throw new Tinebase_Exception_UnexpectedValue('template and definition do not match');
             }
         }
     }
@@ -350,6 +358,25 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
         }
     }
 
+    protected function renderProcessorsTwigTemplate()
+    {
+        if (null === ($src = $this->_currentProcessor->getTwigSource())) {
+            return;
+        }
+
+        $twigName = $this->_currentProcessor->getTwigName() . ' _twig';
+        $this->_twig->addLoader(new Tinebase_Twig_CallBackLoader($twigName, $this->_getLastModifiedTimeStamp(),
+            array($this->_currentProcessor, 'getTwigSource')));
+
+        $result = str_replace("\n", Tinebase_Export_Richtext_TemplateProcessor::NEW_LINE_PLACEHOLDER,
+            $this->_twig->load($twigName)->render($this->_getTwigContext([
+                'records' => $this->_currentIterationRecords,
+                'record'  => null,
+            ])));
+        $this->_currentProcessor->setValue('${TWIG_TEMPLATE}', $result);
+        $this->_currentProcessor->unsetTwigSource();
+    }
+
     /**
      * @param string $_name
      * @param Tinebase_Export_Richtext_TemplateProcessor $_processor
@@ -570,6 +597,7 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
 
             if (empty($this->_dataSources)) {
                 $this->_findAndReplaceGroup($this->_docTemplate);
+                $this->_docTemplate->replaceTwigTemplate();
             }
         }
     }
@@ -588,6 +616,8 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
                 $this->_dataSources[$match[1]] = $processor;
 
                 $this->_findAndReplaceGroup($processor);
+
+                $processor->replaceTwigTemplate();
             }
         }
     }
@@ -622,6 +652,8 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
                     isset($config['recordRow']['groupFooterRow']) || isset($config['recordRow']['groupSeparatorRow']))) {
                 throw new Tinebase_Exception_UnexpectedValue('GROUP with record row must not contain header, footer or separator as table row and group block at the same time');
             }
+            $groupProcessor->replaceTwigTemplate();
+
             $config['groupXml'] = $this->_cutXml($groupProcessor->getMainPart());
             $groupProcessor->setMainPart('<?xml');
             $groupProcessor->setConfig($config);
@@ -663,6 +695,7 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
                 $config['separator'] = $recordSeparator;
             }
             $processor->setConfig(array_merge($processor->getConfig(), $config));
+
             return $processor;
         }
 
@@ -703,7 +736,7 @@ class Tinebase_Export_Doc extends Tinebase_Export_Abstract implements Tinebase_R
                 $result['groupSeparatorRow'] = str_replace('${GROUP_SEPARATOR}', '', $_templateProcessor->replaceRow('${GROUP_SEPARATOR}', ''));
             }
         } else {
-            throw new Tinebase_Exception_UnexpectedValue('template without RECORD_BLOCK needs to contain a table row with a replacement variable');
+            $result = null;
         }
 
         return $result;
