@@ -800,10 +800,12 @@ abstract class ActiveSync_Frontend_Abstract implements Syncroton_Data_IData
      */
     protected function _truncateField($record, $fieldName, $syncrotonValue, $fieldLength = 255)
     {
-        if (mb_strlen($syncrotonValue) > $fieldLength) {
+        if ($fieldLength && mb_strlen($syncrotonValue) > $fieldLength) {
+            $record->$fieldName = mb_substr($syncrotonValue, 0, $fieldLength);
             if (Tinebase_Core::isLogLevel(Zend_Log::NOTICE)) Tinebase_Core::getLogger()->notice(__METHOD__ . '::' . __LINE__
-                . ' field truncated: ' . $fieldName . ' / was: ' . $syncrotonValue);
+                . ' field truncated: ' . $fieldName . ' / was: ' . $syncrotonValue . ' / truncated value: ' . $record->$fieldName);
+        } else {
+            $record->$fieldName = $syncrotonValue;
         }
-        $record->$fieldName = mb_substr($syncrotonValue, 0, $fieldLength);
     }
 }
