@@ -409,6 +409,7 @@ class Tinebase_Frontend_Cli_Abstract
     
     /**
      * import records
+     * Usage example: php tine20.php --method Addressbook.import /path/to/import.vcf -- definition=adb_import_vcard
      *
      * @param Zend_Console_Getopt   $_opts
      * @return array import result
@@ -445,7 +446,8 @@ class Tinebase_Frontend_Cli_Abstract
             $definition = Tinebase_ImportExportDefinition::getInstance()->getGenericImport($args['model']);
             $importer = call_user_func($definition->plugin . '::createFromDefinition', $definition, $args);
         } else {
-            echo "You need to define a plugin OR a definition OR a model at least! \n";
+            echo "You need to define a plugin OR a definition OR a model at least!\n";
+            echo "Usage example: php tine20.php --method Addressbook.import /path/to/import.vcf -- definition=adb_import_vcard\n";
             exit;
         }
         
@@ -628,7 +630,13 @@ class Tinebase_Frontend_Cli_Abstract
 
             $cronuser = Tinebase_User::createSystemUser(Tinebase_User::SYSTEM_USER_CRON);
             if ($cronuser) {
-                Tinebase_Config::getInstance()->set(Tinebase_Config::CRONUSERID, $cronuser->getId());
+                try {
+                    Tinebase_Config::getInstance()->set(Tinebase_Config::CRONUSERID, $cronuser->getId());
+                } catch (Zend_Db_Statement_Exception $zdse) {
+                    if (! Tinebase_Exception::isDbDuplicate($e)) {
+                        throw $zdse;
+                    }
+                }
             }
         }
 
@@ -642,6 +650,7 @@ class Tinebase_Frontend_Cli_Abstract
      * @param string $_model
      * @param string $_exportClass
      * @return boolean
+     * @throws Tinebase_Exception_InvalidArgument
      *
      * TODO use Calendar_Export_VCalendarReport / Addressbook_Export_VCardReport here
      */
@@ -649,18 +658,25 @@ class Tinebase_Frontend_Cli_Abstract
     {
         $args = $this->_parseArgs($_opts);
 
-        // @todo implement
-        //   - allow to export all shared containers
-
-        if (isset($args['type']) && $args['type'] === 'personal') {
+        if (isset($args['type']) && in_array($args['type'], [
+            Tinebase_Model_Container::TYPE_PERSONAL,
+            Tinebase_Model_Container::TYPE_SHARED,
+        ])) {
             // get all containers of given type
-            $containers = Tinebase_Container::getInstance()->getPersonalContainer(
-                Tinebase_Core::getUser(),
-                $_model,
-                Tinebase_Core::getUser()
-            )->getArrayOfIds();
+            $containers = Tinebase_Container::getInstance()->search(new Tinebase_Model_ContainerFilter([
+                ['field' => 'application_id', 'operator' => 'equals', 'value' => Tinebase_Application::getInstance()
+                    ->getApplicationByName($this->_applicationName)->getId()],
+                ['field' => 'model', 'operator' => 'equals', 'value' => $_model],
+                ['field' => 'type', 'operator' => 'equals', 'value' => $args['type']],
+            ]))->getArrayOfIds();
         } else if (isset($args['container_id'])) {
             $containers = explode(',', $args['container_id']);
+        } else {
+            throw new Tinebase_Exception_InvalidArgument('type (personal|shared) or container_id required');
+        }
+
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) {
+            Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__ . ' Got ' . count($containers) . ' containers for export');
         }
 
         foreach ($containers as $containerId) {
@@ -684,7 +700,18 @@ class Tinebase_Frontend_Cli_Abstract
     protected function _getVObjectExportFilename($container, $args, $extension)
     {
         $path = isset($args['path']) ? $args['path'] : Tinebase_Core::getTempDir();
-        return $path . DIRECTORY_SEPARATOR . Tinebase_Core::getUser()->accountLoginName
+        if ($container->type === Tinebase_Model_Container::TYPE_SHARED) {
+            $owner = 'shared';
+        } else {
+            try {
+                $user = Tinebase_User::getInstance()->getFullUserById($container->owner_id);
+                $owner = $user->accountLoginName;
+            } catch (Tinebase_Exception_NotFound $tenf) {
+                $owner = $container->owner_id;
+            }
+        }
+
+        return $path . DIRECTORY_SEPARATOR . $owner
             // . '_' . $container->name
             . '_' . substr($container->getId(), 0, 8) . '.' . $extension;
     }
@@ -716,13 +743,25 @@ class Tinebase_Frontend_Cli_Abstract
         $filter = Tinebase_Model_Filter_FilterGroup::getFilterForModel($model, [
             ['field' => 'container_id', 'operator' => 'equals', 'value' => $containerId],
         ]);
+
         $export = new $exportClass($filter, null, $options);
         $filename = $export->generate();
         if (! $filename) {
             // TODO refactor function signature - write does not write content to file but to stdout/browser
             $export->write();
         } else {
-            echo 'Exported container ' . $containerId . ' into file ' . $filename . "\n";
+            if (isset($options['fm_path'])) {
+                foreach ((array) $filename as $file) {
+                    $tempFile = Tinebase_TempFile::getInstance()->createTempFile($file);
+                    $nodePath = Tinebase_Model_Tree_Node_Path::createFromRealPath($options['fm_path'] ,
+                        Tinebase_Application::getInstance()->getApplicationByName('Filemanager'));
+                    $targetPath = $nodePath->statpath . '/' . basename($file);
+                    Tinebase_FileSystem::getInstance()->copyTempfile($tempFile, $targetPath);
+                    echo 'Exported container ' . $containerId . ' to Filemanager path ' . $options['fm_path'] . '/' . basename($file) ."\n";
+                }
+            } else {
+                echo 'Exported container ' . $containerId . ' into file ' . $filename . "\n";
+            }
         }
     }
 }
