@@ -146,6 +146,27 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
         }
     }
 
+    protected function _getRequestContextHeaders()
+    {
+        $clientData = [];
+        if ($request = Tinebase_Core::getRequest()) {
+            foreach ($request->getHeaders() as $header) {
+                if (strpos(($name = strtoupper($header->getFieldName())), 'X-TINE20-REQUEST-CONTEXT-') === 0) {
+                    $name = strtolower(substr($name, strlen('X-TINE20-REQUEST-CONTEXT-')));
+                    $clientData[$name] = $header->getFieldValue();
+                }
+            }
+        }
+        return $clientData;
+    }
+
+    protected function _setRequestContext(Tinebase_Controller_Abstract $controller)
+    {
+        $context = $controller->getRequestContext() ?: [];
+        $context['clientData'] = $this->_getRequestContextHeaders();
+        $controller->setRequestContext($context);
+    }
+
     /**
      * @param string $_uid
      * @param Tinebase_Controller_Record_Interface $_controller
@@ -154,6 +175,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _get($_uid, Tinebase_Controller_Record_Interface $_controller)
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         $record = $_controller->get($_uid);
         if (! $record) {
             throw new Tinebase_Exception_NotFound('record not found');
@@ -172,6 +197,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _getAll(Tinebase_Controller_Record_Interface $_controller)
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         $records = $_controller->getAll();
 
         return array(
@@ -184,7 +213,7 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      * Search for records matching given arguments
      *
      * @param string|array                        $_filter json encoded / array
-     * @param string|array                        $_paging json encoded / array
+     * @param string|array|Tinebase_Model_Pagination $_paging json encoded / array
      * @param Tinebase_Controller_SearchInterface $_controller the record controller
      * @param string                              $_filterModel the class name of the filter model to use
      * @param bool|array|Tinebase_Record_Expander $_getRelations
@@ -193,14 +222,12 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _search($_filter, $_paging, Tinebase_Controller_SearchInterface $_controller, $_filterModel, $_getRelations = FALSE, $_totalCountMethod = self::TOTALCOUNT_CONTROLLER)
     {
-        $filter = $this->_decodeFilter($_filter, $_filterModel);
-        $decodedPagination = $this->_prepareParameter($_paging);
-        if (null !== $this->_paginationModel) {
-            $decodedPagination['model'] = $this->_paginationModel;
-        } else {
-            $decodedPagination['model'] = $filter->getModelName();
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
         }
-        $pagination = new Tinebase_Model_Pagination($decodedPagination);
+
+        $filter = $this->_decodeFilter($_filter, $_filterModel);
+        $pagination = $this->_preparePaginationParameter($_paging, $filter);
         $records = $_controller->search($filter, $pagination, $_getRelations);
 
         $result = $this->_multipleRecordsToJson($records, $filter);
@@ -212,6 +239,34 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
         ]);
     }
 
+    /**
+     * @param mixed $_paging
+     * @param Tinebase_Model_Filter_FilterGroup $_filter
+     * @return Tinebase_Model_Pagination
+     * @throws Tinebase_Exception_Record_DefinitionFailure
+     * @throws Tinebase_Exception_Record_Validation
+     */
+    protected function _preparePaginationParameter($_paging, Tinebase_Model_Filter_FilterGroup $_filter = null)
+    {
+        if ($_paging instanceof Tinebase_Model_Pagination) {
+            return $_paging;
+        }
+
+        $decodedPagination = $this->_prepareParameter($_paging);
+        if (! is_array($decodedPagination)) {
+            $decodedPagination = [
+                'start' => 0,
+                'limit' => 50,
+            ];
+        }
+        if (null !== $this->_paginationModel) {
+            $decodedPagination['model'] = $this->_paginationModel;
+        } else if ($_filter) {
+            $decodedPagination['model'] = $_filter->getModelName();
+        }
+        return new Tinebase_Model_Pagination($decodedPagination);
+    }
+
     /**
      * do search count request only when resultset is equal
      * to $pagination->limit or we are not on the first page
@@ -225,6 +280,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _getSearchTotalCount($filter, $pagination, $controller, $totalCountMethod, $resultCount)
     {
+        if ($controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($controller);
+        }
+
          if (   $totalCountMethod === self::TOTALCOUNT_CONTROLLER
             && $pagination->limit
             && ($pagination->start != 0 || $resultCount == $pagination->limit)
@@ -281,6 +340,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _save($_recordData, Tinebase_Controller_Record_Interface $_controller, $_modelName, $_identifier = 'id', $_additionalArguments = array())
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         $modelClass = (preg_match('/_Model_/', $_modelName)) ? $_modelName : $this->_applicationName . "_Model_" . $_modelName;
         $record = $this->_jsonToRecord($_recordData, $modelClass);
 
@@ -346,6 +409,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _updateMultiple($_filter, $_data, Tinebase_Controller_Record_Interface $_controller, $_filterModel)
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         $this->_longRunningRequest();
         $decodedData   = $this->_prepareParameter($_data);
         $filter = $this->_decodeFilter($_filter, $_filterModel, TRUE);
@@ -387,6 +454,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _updateProperties($_id, $_data, Tinebase_Controller_Record_Interface $_controller)
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         $record = $_controller->get($_id);
 
         // merge with new properties
@@ -409,6 +480,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _delete($_ids, Tinebase_Controller_Record_Interface $_controller, $additionalArguments = array())
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         if (! is_array($_ids) && strpos($_ids, '[') !== false) {
             $_ids = $this->_prepareParameter($_ids);
         }
@@ -462,6 +537,10 @@ abstract class Tinebase_Frontend_Json_Abstract extends Tinebase_Frontend_Abstrac
      */
     protected function _deleteByFilter($_filter, Tinebase_Controller_Record_Interface $_controller, $_filterModel)
     {
+        if ($_controller instanceof Tinebase_Controller_Abstract) {
+            $this->_setRequestContext($_controller);
+        }
+
         $filter = $this->_decodeFilter($_filter, $_filterModel, TRUE);
         
         // extend execution time to 30 minutes
