@@ -24,7 +24,10 @@ class Tinebase_Log_Formatter_Json extends Tinebase_Log_Formatter
     public function format($event)
     {
         $data = $this->getLogData($event);
-
+        
+        // filebeat friendly format, make sure you have set "json.overwrite_keys: true" in your filebeat conf
+        $data['@timestamp'] = date(sprintf('Y-m-d\TH:i:s%s\Z', substr(microtime(), 1, 4)));
+        
         return @json_encode($data,
             JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE | JSON_PRESERVE_ZERO_FRACTION)
             . PHP_EOL;
