@@ -3,7 +3,7 @@
  * @package     Calendar
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Cornelius Weiss <c.weiss@metaways.de>
- * @copyright   Copyright (c) 2009-2018 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2009-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 /**
@@ -17,6 +17,7 @@
  * @property string status
  * @property string status_authkey
  * @property string user_type
+ * @property string displaycontainer_id
  */
 class Calendar_Model_Attender extends Tinebase_Record_Abstract
 {
@@ -27,7 +28,6 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
     const USERTYPE_GROUP       = 'group';
     const USERTYPE_GROUPMEMBER = 'groupmember';
     const USERTYPE_RESOURCE    = 'resource';
-    const USERTYPE_LIST        = 'list';
     const USERTYPE_ANY         = 'any';
 
     /**
@@ -56,7 +56,6 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
         self::USERTYPE_USER        => array(),
         self::USERTYPE_GROUPMEMBER => array(),
         self::USERTYPE_GROUP       => array(),
-        self::USERTYPE_LIST        => array(),
         self::USERTYPE_RESOURCE    => array(),
         Calendar_Model_AttenderFilter::USERTYPE_MEMBEROF => array()
     );
@@ -294,7 +293,6 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                 return $translation->translate('User');
             case self::USERTYPE_GROUPMEMBER:
                 return $translation->translate('Member of group');
-            case self::USERTYPE_LIST:
             case self::USERTYPE_GROUP:
                 return $translation->translate('Group');
             case self::USERTYPE_RESOURCE:
@@ -451,7 +449,12 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
             
             $_event->attendee->removeRecord($attendeeToDelete);
         }
-        
+
+        /* that's what I had in mind, but churchedition comes with custom system roles ...
+        $systemRoles = Calendar_Config::getInstance()->{Calendar_Config::ATTENDEE_ROLES}->records
+            ->filter('system', true)->getArrayOfIds(); */
+        $systemRoles = ['REQ', 'OPT'];
+
         // attendees to keep and update
         $attendeesToKeep   = array_diff_key($emailsOfCurrentAttendees, $attendeesToDelete);
         if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ . " attendees to keep " . print_r(array_keys($attendeesToKeep), true));
@@ -461,7 +464,8 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
 
             // update object by reference
             $attendeeToKeep->status = isset($newSettings['partStat']) ? $newSettings['partStat'] : $attendeeToKeep->status;
-            $attendeeToKeep->role   = $newSettings['role'];
+            $attendeeToKeep->role   = isset($newSettings['role']) && in_array($newSettings['role'], $systemRoles) &&
+                (!isset($attendeesToKeep['role']) || in_array($attendeesToKeep['role'], $systemRoles)) ? $newSettings['role'] : $attendeesToKeep['role'];
         }
 
         // new attendess to add to event
@@ -481,6 +485,15 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                 ) {
                     $newAttendee['userType'] = Calendar_Model_Attender::USERTYPE_GROUP;
                     $attendeeId = $matches[1];
+
+                    try {
+                        $list = Addressbook_Controller_List::getInstance()->get($attendeeId);
+                        if ($list && $list->type === Addressbook_Model_List::LISTTYPE_GROUP) {
+                            $attendeeId = $list->group_id;
+                        }
+                    } catch (Exception $e) {
+                        // do nothing
+                    }
                 }
 
                 // does a contact with this email address exist?
@@ -525,9 +538,9 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                     try {
                         $listId = explode('@', $newAttendee['email'])[0];
                         $list = Addressbook_Controller_List::getInstance()->get($listId);
-                        if ($list) {
+                        if ($list && $list->type === Addressbook_Model_List::LISTTYPE_GROUP) {
                             $newAttendee['userType'] = Calendar_Model_Attender::USERTYPE_GROUP;
-                            $attendeeId = $list->getId();
+                            $attendeeId = $list->group_id;
                         }
                     } catch (Exception $e) {
                         // do nothing
@@ -843,7 +856,6 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
             self::USERTYPE_USER        => array(),
             self::USERTYPE_GROUPMEMBER => array(),
             self::USERTYPE_GROUP       => array(),
-            self::USERTYPE_LIST        => array(),
             self::USERTYPE_RESOURCE    => array(),
             Calendar_Model_AttenderFilter::USERTYPE_MEMBEROF => array()
         );
@@ -1092,7 +1104,8 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                 case Calendar_Model_AttenderFilter::USERTYPE_MEMBEROF:
                     // first fetch the groups, then the lists identified by list_id
                     $typeMap[$type] = Tinebase_Group::getInstance()->getMultiple(array_unique($ids));
-                    $typeMap[self::USERTYPE_LIST] = Addressbook_Controller_List::getInstance()->getMultiple($typeMap[$type]->list_id, true);
+                    $listIds = array_unique(array_merge($typeMap[$type]->list_id, $ids));
+                    $typeMap['list'] = Addressbook_Controller_List::getInstance()->getMultiple($listIds, true);
                     break;
                 case self::USERTYPE_RESOURCE:
                     $typeMap[$type] = Calendar_Controller_Resource::getInstance()->getMultiple(array_unique($ids), true);
@@ -1128,8 +1141,11 @@ class Calendar_Model_Attender extends Tinebase_Record_Abstract
                     $idx = $attendeeTypeSet->getIndexById($attender->user_id);
                     if ($idx !== false) {
                         $group = $attendeeTypeSet[$idx];
-                        $attendeeTypeSet = $typeMap[self::USERTYPE_LIST];
+                        $attendeeTypeSet = $typeMap['list'];
                         $idx = $attendeeTypeSet->getIndexById($group->list_id);
+                    } else {
+                        $attendeeTypeSet = $typeMap['list'];
+                        $idx = $attendeeTypeSet->getIndexById($attender->user_id);
                     }
                 } else {
                     $attendeeTypeSet = $typeMap[$attender->user_type];
