@@ -760,6 +760,9 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
     
     /**
      * returns TRUE if comparison detects a resechedule / significant change
+     *
+     * ATTENTION: is may not be reversable all the time (because of the rrule logic below)
+     * $event1->isRescheduled($event2) !== $event2->isRescheduled($event1)
      * 
      * @param  Calendar_Model_Event $_event
      * @return bool
@@ -767,7 +770,17 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
     public function isRescheduled($_event)
     {
         $diff = $this->diff($_event)->diff;
-        
+
+        if (isset($diff['rrule']) && $diff['rrule'] instanceof Tinebase_Record_Diff) {
+            $rrDiff = $diff['rrule']->diff;
+            if (isset($rrDiff['count']) && (int)$rrDiff['count'] > (int)$diff['rrule']->oldData['count']) {
+                unset($rrDiff['count']);
+            }
+            if (empty($rrDiff)) {
+                unset($diff['rrule']);
+            }
+        }
+
         return (isset($diff['dtstart']) || array_key_exists('dtstart', $diff))
             || (! $this->is_all_day_event && (isset($diff['dtend']) || array_key_exists('dtend', $diff)))
             || (isset($diff['rrule']) || array_key_exists('rrule', $diff));
@@ -870,6 +883,9 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
         }
     }
 
+    /**
+     * @return boolean
+     */
     public function isReplicable()
     {
         $container = $this->container_id;
@@ -880,7 +896,8 @@ class Calendar_Model_Event extends Tinebase_Record_Abstract
             try {
                 $container = Tinebase_Container::getInstance()->getContainerById($container);
             } catch (Tinebase_Exception_NotFound $e) {
-                Tinebase_Exception::log($e);
+                if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(
+                    __METHOD__ . '::' . __LINE__ . ' ' . $e->getMessage());
                 return false;
             }
         }
