@@ -634,7 +634,8 @@ class Tinebase_Model_Filter_FilterGroup implements Iterator
                 // NOTE: maybe this should be fixed in the client / this is just sanitizing here
                 // equals is also valid (for Tinebase_Model_Filter_ForeignId)
                 // TODO this needs to go away!
-                if (! in_array($data['operator'], [self::CONDITION_OR, self::CONDITION_AND, 'equals', 'in', 'not', 'notin', 'notDefinedBy:AND'])) {
+                if (! in_array($data['operator'], [self::CONDITION_OR, self::CONDITION_AND, 'equals', 'in', 'not', 'notin', 'notDefinedBy:AND']) &&
+                        strpos($data['operator'], 'efinedBy') === false) {
                     // add a sub-query filter
                     $data['value'] = [
                         ['field' => 'query', 'operator' => $data['operator'], 'value' => $data['value']]
