@@ -35,8 +35,9 @@
  * @property    integer $reading_conf       true if it must send a reading confirmation
  * @property    boolean $massMailingFlag    true if message should be treated as mass mailing
  * @property    array   $fileLocations      file locations of this message
+ * @property    boolean $is_spam_suspicions true if is spam suspicions
  */
-class Felamimail_Model_Message extends Tinebase_Record_Abstract
+class Felamimail_Model_Message extends Tinebase_Record_Abstract implements Tinebase_BL_DataInterface
 {
     /**
      * message content type (rfc822)
@@ -170,6 +171,7 @@ class Felamimail_Model_Message extends Tinebase_Record_Abstract
             array('InArray', array(0, 1)),
         ),
         'fileLocations'         => array(Zend_Filter_Input::ALLOW_EMPTY => true),
+        'is_spam_suspicions'    => array(Zend_Filter_Input::ALLOW_EMPTY => true),
     );
     
     /**
@@ -380,8 +382,7 @@ class Felamimail_Model_Message extends Tinebase_Record_Abstract
             $message = new Felamimail_Model_Message();
             $message->account_id = $this->account_id;
             
-            $punycodeConverter = Felamimail_Controller_Message::getInstance()->getPunycodeConverter();
-            $to = Felamimail_Message::convertAddresses($this->headers['disposition-notification-to'], $punycodeConverter);
+            $to = Felamimail_Message::convertAddresses($this->headers['disposition-notification-to']);
             if (empty($to)) {
                 throw new Felamimail_Exception('disposition-notification-to header does not contain a valid email address');
             }
@@ -431,17 +432,16 @@ class Felamimail_Model_Message extends Tinebase_Record_Abstract
             $this->message_id = $_headers['message-id'];
         }
 
-        $punycodeConverter = Felamimail_Controller_Message::getInstance()->getPunycodeConverter();
         foreach (array('to', 'cc', 'bcc', 'from', 'sender') as $field) {
             if (isset($_headers[$field])) {
                 if (is_array($_headers[$field])) {
                     $value = array();
                     foreach ($_headers[$field] as $headerValue) {
-                        $value = array_merge($value, Felamimail_Message::convertAddresses($headerValue, $punycodeConverter));
+                        $value = array_merge($value, Felamimail_Message::convertAddresses($headerValue));
                     }
                     $this->$field = $value;
                 } else {
-                    $value = Felamimail_Message::convertAddresses($_headers[$field], $punycodeConverter);
+                    $value = Felamimail_Message::convertAddresses($_headers[$field]);
                     switch ($field) {
                         case 'from':
                             $this->from_email = (isset($value[0]) && (isset($value[0]['email']) || array_key_exists('email', $value[0]))) ? $value[0]['email'] : '';
@@ -844,6 +844,7 @@ class Felamimail_Model_Message extends Tinebase_Record_Abstract
                     if (empty($recipient)) {
                         unset($recipients[$key]);
                     }
+                    $recipient = trim($recipient);
                 }
                 unset($recipient);
 
