@@ -122,6 +122,22 @@ class Tinebase_Model_Tree_Node_Path extends Tinebase_Record_Abstract
         return $pathRecord;
     }
 
+    /**
+     * create new path record from given realpath string like this:
+     *  /personal/tine20admin/somedir
+     *
+     * @param string|Tinebase_Model_Tree_Node_Path $_path
+     * @return Tinebase_Model_Tree_Node_Path
+     */
+    public static function createFromRealPath($_path, $_application, $part = self::FOLDERS_PART)
+    {
+        $flatpath = '/' . $_application->name . '/' . $part . $_path;
+        return new Tinebase_Model_Tree_Node_Path(array(
+            'application' => $_application,
+            'flatpath'  => $flatpath
+        ));
+    }
+
     /**
      * create new path record from given stat path (= path with ids) string
      *
@@ -246,9 +262,6 @@ class Tinebase_Model_Tree_Node_Path extends Tinebase_Record_Abstract
             $_path = $this->flatpath;
         }
         
-        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ 
-            . ' Parsing path: ' . $_path);
-        
         $pathParts = $this->_getPathParts($_path);
         
         $this->name                 = $pathParts[count($pathParts) - 1];
@@ -364,12 +377,7 @@ class Tinebase_Model_Tree_Node_Path extends Tinebase_Record_Abstract
             }
             $this->flatpath = '/' . implode('/', $pathParts);
         }
-        $result = $this->_createStatPathFromParts($pathParts);
-        
-        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__ 
-            . ' Path to stat: ' . $result);
-        
-        return $result;
+        return $this->_createStatPathFromParts($pathParts);
     }
     
     /**
@@ -380,8 +388,6 @@ class Tinebase_Model_Tree_Node_Path extends Tinebase_Record_Abstract
      */
     protected function _createStatPathFromParts($pathParts)
     {
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__ . ' ' . print_r($pathParts, TRUE));
-        
         if (count($pathParts) > 3) {
             // replace account login name with id
             if ($this->containerOwner) {
