@@ -18,6 +18,7 @@
 
 class Tinebase_ModelConfiguration_Const {
     const ADD_FILTERS = 'addFilters';
+    const APPLICATION = 'application';
     const APP_NAME = 'appName';
     const ASSOCIATIONS = 'associations';
     const AVAILABLE_MODELS = 'availableModels';
@@ -36,12 +37,18 @@ class Tinebase_ModelConfiguration_Const {
     const DEFAULT_VAL = 'default';
     const DEGREE = 'degree';
     const DEPENDENT_RECORDS = 'dependentRecords';
+    /**
+     * UI ONLY - If this is set to true, the field can't be updated and will not be shown in the frontend
+     */
     const DISABLED = 'disabled';
+    const DOCTRINE_IGNORE = 'doctrineIgnore';
 
+    const EXPORT = 'export';
     const EXPOSE_HTTP_API = 'exposeHttpApi';
     const EXPOSE_JSON_API = 'exposeJsonApi';
 
     const FIELDS = 'fields';
+    const FIELD_NAME = 'fieldName';
     const FILTER = 'filter';
     const FILTER_CLASS_NAME = 'filterClassName';
     const FILTER_DEFINITION = 'filterDefinition';
@@ -55,7 +62,10 @@ class Tinebase_ModelConfiguration_Const {
     const HAS_CUSTOM_FIELDS = 'hasCustomFields';
     const HAS_DELETED_TIME_UNIQUE = 'hasDeletedTimeUnique';
     const HAS_NOTES = 'hasNotes';
+    const CONTAINER_PROPERTY = 'containerProperty';
     const HAS_PERSONAL_CONTAINER = 'hasPersonalContainer';
+    const CONTAINER_NAME = 'containerName';
+    const CONTAINERS_NAME = 'containersName';
     const HAS_RELATIONS = 'hasRelations';
     const HAS_SYSTEM_CUSTOM_FIELDS = 'hasSystemCustomFields';
     const HAS_TAGS = 'hasTags';
@@ -68,6 +78,8 @@ class Tinebase_ModelConfiguration_Const {
     const IS_DEPENDENT = 'isDependent';
     const IS_VIRTUAL = 'isVirtual';
 
+    const JOIN_COLUMNS = 'joinColumns';
+
     const LABEL = 'label';
     const LENGTH = 'length';
 
@@ -78,13 +90,22 @@ class Tinebase_ModelConfiguration_Const {
     const NULLABLE = 'nullable';
 
     const OMIT_MOD_LOG = 'modlogOmit';
+    const ON_DELETE = 'onDelete';
+    const ON_UPDATE = 'onUpdate';
     const OPTIONS = 'options';
+    // used for example by system customfields. Tells the receiving model, that this property originates from a different app
+    // relevant for translation, keyfields, etc.
+    const OWNING_APP = 'owningApp';
 
     const PAGING = 'paging';
 
     const QUERY_FILTER = 'queryFilter';
 
+    /**
+     * If this is set to true, the field can't be updated in BE and will be shown as readOnly in the frontend
+     */
     const READ_ONLY = 'readOnly';
+    const REFERENCED_COLUMN_NAME = 'referencedColumnName';
     const REF_ID_FIELD = 'refIdField';
     const REF_MODEL_FIELD = 'refModelField';
     const RECORD_CLASS_NAME = 'recordClassName';
@@ -92,14 +113,19 @@ class Tinebase_ModelConfiguration_Const {
     const RECORDS_NAME = 'recordsName';
     const RUN_CONVERT_TO_RECORD_FROM_JSON = 'runConvertToRecordFromJson';
 
+    /**
+     * frontends do not show this field in grids per default
+     */
     const SHY = 'shy';
     const SINGULAR_CONTAINER_MODE = 'singularContainerMode';
     const SPECIAL_TYPE = 'specialType';
     const SPECIAL_TYPE_DURATION_SEC = 'durationSec';
     const STORAGE = 'storage';
+    const SUPPORTED_FORMATS = 'supportedFormats';
     const SYSTEM = 'system';
 
     const TABLE = 'table';
+    const TARGET_ENTITY = 'targetEntity';
     const TITLE_PROPERTY = 'titleProperty';
     const TYPE = 'type';
     const TYPE_ATTACHMENTS = 'attachments';
@@ -133,6 +159,7 @@ class Tinebase_ModelConfiguration_Const {
 
     const UNIQUE_CONSTRAINTS = 'uniqueConstraints';
     const UNSIGNED = 'unsigned';
+    const UI_CONFIG = 'uiconfig';
 
     const VALIDATORS = 'validators';
     const VERSION = 'version';
