@@ -523,6 +523,7 @@ class Tinebase_Notes implements Tinebase_Backend_Sql_Interface
                             $recordProperties[$attribute]['config']['controllerClassName']::getInstance()) &&
                             method_exists($controller, 'get')) {
                         if ($oldData) {
+                            if (is_array($oldData)) $oldData = isset($oldData['id']) ? $oldData['id'] : '';
                             try {
                                 $oldDataString = $controller->get($oldData, null, false, true)->getTitle();
                             } catch (Tinebase_Exception_NotFound $tenf) {
@@ -534,6 +535,7 @@ class Tinebase_Notes implements Tinebase_Backend_Sql_Interface
                             $oldDataString = '';
                         }
                         if ($value) {
+                            if (is_array($value)) $value = isset($value['id']) ? $value['id'] : '';
                             try {
                                 $valueString = $controller->get($value, null, false, true)->getTitle();
                             } catch(Tinebase_Exception_NotFound $e) {
@@ -901,14 +903,14 @@ class Tinebase_Notes implements Tinebase_Backend_Sql_Interface
     }
 
     /**
-     * Updates multiple entries
+     * update multiple records
      *
-     * @param array $_ids to update
+     * @param Tinebase_Model_Filter_FilterGroup $_filter
      * @param array $_data
-     * @return integer number of affected rows
+     * @param Tinebase_Model_Pagination $_pagination
      * @throws Tinebase_Exception_NotImplemented
      */
-    public function updateMultiple($_ids, $_data)
+    public function updateMultiple($_filter, $_data, $_pagination = null)
     {
         throw new Tinebase_Exception_NotImplemented(__METHOD__ . ' is not implemented');
     }
