@@ -1180,7 +1180,7 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
      */
     public function isEqual($_record, array $_toOmit = array())
     {
-        $diff = $this->diff($_record);
+        $diff = $this->diff($_record, $_toOmit);
         return ($diff) ? $diff->isEmpty($_toOmit) : FALSE;
     }
     
@@ -1289,6 +1289,7 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
      * set read only fields
      *
      * @param array $readOnlyFields
+     * @deprecated is defined by modelconfig and should not be changed afterwards
      */
     public function setReadOnlyFields($readOnlyFields)
     {
@@ -1521,9 +1522,16 @@ abstract class Tinebase_Record_Abstract extends Tinebase_ModelConfiguration_Cons
     }
 
     /**
-     * @param array $_defintiion
+     * @param array $_definition
      */
-    public static function inheritModelConfigHook(array &$_defintion)
+    public static function inheritModelConfigHook(array &$_definition)
+    {
+    }
+
+    /**
+     * @param array $_definition
+     */
+    public static function modelConfigHook(array &$_definition)
     {
     }
 
