@@ -6,7 +6,7 @@
  * @subpackage  Record
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Paul Mehrer <p.mehrer@metaways.de>
- * @copyright   Copyright (c) 2018-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2018-2021 Metaways Infosystems GmbH (http://www.metaways.de)
  *
  */
 
@@ -32,13 +32,18 @@ class Tinebase_Record_Expander_Factory
         if (!$mc->hasField($_property)) {
             throw new Tinebase_Exception_InvalidArgument($_model . ' doesn\'t have property ' . $_property);
         }
-        if (null === ($propModel = $mc->getFieldModel($_property)) ) {
-            throw new Tinebase_Exception_NotImplemented($_model . '::' . $_property . ' has a unknown model');
-        }
         $fieldDef = $mc->getFields()[$_property];
         if (!isset($fieldDef[MCC::TYPE])) {
             throw new Tinebase_Exception_InvalidArgument($_model . '::' . $_property . ' has not type');
         }
+        // hrmpf legacy
+        if (isset($fieldDef[MCC::CONFIG][MCC::FUNCTION])) {
+            return new Tinebase_Record_Expander_VirtualFunction($fieldDef[MCC::CONFIG],
+                null, $_property, $_definition, $_rootExpander);
+        }
+        if (null === ($propModel = $mc->getFieldModel($_property)) ) {
+            throw new Tinebase_Exception_NotImplemented($_model . '::' . $_property . ' has a unknown model');
+        }
 
         $prio = null;
         switch ($fieldDef[MCC::TYPE]) {
@@ -51,6 +56,10 @@ class Tinebase_Record_Expander_Factory
                     $prio = Tinebase_Record_Expander_Abstract::DATA_FETCH_PRIO_CONTAINER;
                 }
             case MCC::TYPE_RECORD:
+                if (isset($fieldDef[MCC::CONFIG][MCC::DEPENDENT_RECORDS]) && $fieldDef[MCC::CONFIG][MCC::DEPENDENT_RECORDS]) {
+                    return new Tinebase_Record_Expander_DependentRecordProperty($fieldDef, $propModel, $_property, $_definition,
+                        $_rootExpander, $prio ?: Tinebase_Record_Expander_Abstract::DATA_FETCH_PRIO_DEPENDENTRECORD);
+                }
                 return new Tinebase_Record_Expander_RecordProperty($propModel, $_property, $_definition, $_rootExpander,
                      $prio ?: Tinebase_Record_Expander_Abstract::DATA_FETCH_PRIO_DEPENDENTRECORD);
             case MCC::TYPE_RECORDS:
