@@ -5,7 +5,7 @@
  * @package     Tinebase
  * @subpackage  Setup
  * @license     http://www.gnu.org/licenses/agpl.html AGPL3
- * @copyright   Copyright (c) 2019-2019 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2019-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  * @author      Paul Mehrer <p.mehrer@metaways.de>
  */
 class Tinebase_Setup_Update_13 extends Setup_Update_Abstract
@@ -14,6 +14,7 @@ class Tinebase_Setup_Update_13 extends Setup_Update_Abstract
     const RELEASE013_UPDATE002 = __CLASS__ . '::update002';
     const RELEASE013_UPDATE003 = __CLASS__ . '::update003';
     const RELEASE013_UPDATE004 = __CLASS__ . '::update004';
+    const RELEASE013_UPDATE005 = __CLASS__ . '::update005';
 
     static protected $_allUpdates = [
         self::PRIO_TINEBASE_STRUCTURE   => [
@@ -35,6 +36,10 @@ class Tinebase_Setup_Update_13 extends Setup_Update_Abstract
                 self::CLASS_CONST                   => self::class,
                 self::FUNCTION_CONST                => 'update003',
             ],
+            self::RELEASE013_UPDATE005          => [
+                self::CLASS_CONST                   => self::class,
+                self::FUNCTION_CONST                => 'update005',
+            ],
         ]
     ];
 
@@ -80,4 +85,25 @@ class Tinebase_Setup_Update_13 extends Setup_Update_Abstract
         Tinebase_Scheduler_Task::addLogEntryCleanUpTask(Tinebase_Core::getScheduler());
         $this->addApplicationUpdate('Tinebase', '13.3', self::RELEASE013_UPDATE004);
     }
+
+    /**
+     * move dblclick action config to tinebase
+     * 
+     * @throws Tinebase_Exception_InvalidArgument
+     * @throws Tinebase_Exception_NotFound
+     * @throws Zend_Db_Adapter_Exception
+     */
+    public function update005()
+    {
+        $db = $this->getDb();
+        $db->update(
+            SQL_TABLE_PREFIX . 'preferences', [
+                'application_id' => Tinebase_Application::getInstance()->getApplicationByName('Tinebase')->getId(),
+                'name' => Tinebase_Preference::FILE_DBLCLICK_ACTION
+            ],
+            $db->quoteInto('name = ?', 'dbClickAction')
+        );
+        
+        $this->addApplicationUpdate('Tinebase', '13.4', self::RELEASE013_UPDATE005);
+    }
 }
