@@ -539,22 +539,18 @@ class Tinebase_Tags
 
         Tinebase_Backend_Sql_Abstract::traitGroup($select);
 
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-            . ' ' . $select);
-
         $queryResult = $this->_db->fetchAll($select);
 
-        if (Tinebase_Core::isLogLevel(Zend_Log::TRACE)) Tinebase_Core::getLogger()->trace(__METHOD__ . '::' . __LINE__
-            . ' ' . print_r($queryResult, TRUE));
-
         // build array with tags (record_id => array of Tinebase_Model_Tag)
         $tagsOfRecords = array();
         foreach ($queryResult as $result) {
             $tagsOfRecords[$result['record_id']][] = new Tinebase_Model_Tag($result, true);
         }
 
-        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
-            . ' Getting ' . count($tagsOfRecords) . ' tags for ' . count($_records) . ' records.');
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG) && count($tagsOfRecords) > 0) {
+            Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+                . ' Getting ' . count($tagsOfRecords) . ' tags for ' . count($_records) . ' records.');
+        }
 
         $result = new Tinebase_Record_RecordSet(Tinebase_Model_Tag::class);
         foreach ($_records as $record) {
