@@ -6,7 +6,7 @@
  * @subpackage  File
  * @license     http://www.gnu.org/licenses/agpl.html AGPL Version 3
  * @author      Cornelius Weiss <c.weiss@metaways.de>
- * @copyright   Copyright (c) 2007-2017 Metaways Infosystems GmbH (http://www.metaways.de)
+ * @copyright   Copyright (c) 2007-2020 Metaways Infosystems GmbH (http://www.metaways.de)
  */
 
 /**
@@ -309,23 +309,45 @@ class Tinebase_TempFile extends Tinebase_Backend_Sql_Abstract implements Tinebas
         if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
             . ' Removed ' . $result . ' temp files from database and filesystem.');
 
-        $result = 0;
-        foreach (new DirectoryIterator(Tinebase_Core::getTempDir()) as $directoryIterator) {
+        $numberOfDeletedFiles = $this->_removeFilesFromDirByTimestamp(Tinebase_Core::getTempDir(), $date);
+        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
+            . ' Removed ' . $numberOfDeletedFiles . ' temp files from filesystem only.');
+
+        return true;
+    }
+
+    /**
+     * @param string $dir
+     * @param Tinebase_DateTime $date
+     * @return int
+     */
+    protected function _removeFilesFromDirByTimestamp($dir, Tinebase_DateTime $date)
+    {
+        if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
+            . ' Deleting old files from dir: ' . $dir);
+
+        $numberOfDeletedFiles = 0;
+        foreach (new DirectoryIterator($dir) as $directoryIterator) {
             $filename = $directoryIterator->getFilename();
-            // preserve directories and dot-files
-            if (strpos($filename, '.') !== 0 && $directoryIterator->isFile() && $date->isLater(new Tinebase_DateTime($directoryIterator->getMTime()))) {
+            if (strpos($filename, '.') === 0) {
+                // do nothing with dotfiles
+                continue;
+            }
+
+            if ($directoryIterator->isFile() && $date->isLater(new Tinebase_DateTime($directoryIterator->getMTime()))) {
                 if (Tinebase_Core::isLogLevel(Zend_Log::DEBUG)) Tinebase_Core::getLogger()->debug(__METHOD__ . '::' . __LINE__
                     . ' Deleting file ' . $filename);
                 unlink($directoryIterator->getPathname());
-                ++$result;
+                ++$numberOfDeletedFiles;
+            } else if ($directoryIterator->isDir()) {
+                // delete sub dir contents, too
+                $numberOfDeletedFiles += $this->_removeFilesFromDirByTimestamp($directoryIterator->getPathname(), $date);
             }
 
             Tinebase_Lock::keepLocksAlive();
         }
-        if (Tinebase_Core::isLogLevel(Zend_Log::INFO)) Tinebase_Core::getLogger()->info(__METHOD__ . '::' . __LINE__
-            . ' Removed ' . $result . ' temp files from filesystem only.');
 
-        return true;
+        return $numberOfDeletedFiles;
     }
     
     /**
@@ -354,20 +376,30 @@ class Tinebase_TempFile extends Tinebase_Backend_Sql_Abstract implements Tinebas
         return $handle;
     }
 
-    public function createTempFileFromNode($node)
+    public function createTempFileFromNode(Tinebase_Model_Tree_Node $node)
     {
-        $content = Tinebase_FileSystem::getInstance()->getNodeContents($node);
         $path = self::getTempPath();
-        file_put_contents($path, $content);
-        return $this->createTempFile($path);
+        if (!copy($node->getFilesystemPath(), $path)) {
+            Tinebase_Core::getLogger()->err('could not copy node ' . $node->getId() . ' ' . $node->getFilesystemPath()
+                . ' to temppath ' . $path);
+            throw new Tinebase_Exception_Backend('could not copy node to tempPath');
+        }
+
+        return $this->createTempFile($path, $node->name, $node->contenttype, $node->size);
     }
 
-    public function createTempFileFromStream($stream)
+    /**
+     * @param resource $stream
+     * @param string $name
+     * @param string $type
+     * @return Tinebase_Model_TempFile
+     */
+    public function createTempFileFromStream($stream, $name = 'tempfile.tmp', $type = 'unknown')
     {
         $content = stream_get_contents($stream);
         $path = self::getTempPath();
         file_put_contents($path, $content);
-        return $this->createTempFile($path);
+        return $this->createTempFile($path, $name, $type);
     }
 
     /**
