@@ -256,7 +256,7 @@ class Tinebase_User_ActiveDirectory extends Tinebase_User_Ldap
         
         $this->_db->update(SQL_TABLE_PREFIX . 'accounts', $values, $where);
         
-        $this->_setPluginsPassword($user->getId(), $_password, $_encrypt);
+        $this->_setPluginsPassword($user, $_password, $_encrypt);
     }
     
     /**
