@@ -980,6 +980,11 @@ class Tinebase_User_Sql extends Tinebase_User_Abstract
 
         // add email user xprops here if configured
         if (Tinebase_EmailUser::isEmailUserPlugin($plugin) && Tinebase_Config::getInstance()->{Tinebase_Config::EMAIL_USER_ID_IN_XPROPS}) {
+            if ($method === 'inspectAddUser' && empty($user->accountEmailAddress)) {
+                // do not add plugin user if user has no email adress
+                return;
+            }
+
             $pluginUser = clone($user);
             Tinebase_EmailUser_XpropsFacade::setIdFromXprops($user, $pluginUser, $method !== 'inspectGetUserByProperty');
             if ($newUserProperties) {
