@@ -865,30 +865,20 @@ Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
 , "All Contacts"
 : "Alle Kontakte"
 
+, "GENDER_Contact"
+: "male"
 
+, "GENDER_List"
+: "female"
 
+, "GENDER_List Function"
+: "female"
 
+, "Addressbooks to export"
+: "Zu exportierende Adressbücher"
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+, "Export target"
+: "Exportzielr"
 
 , "Addressbook"
 : "Adressbuch"
