@@ -911,7 +911,7 @@ Tine.__translationData.msgs['./LC_MESSAGES/Admin'] = ({
 : "Deaktiviert"
 
 , "Enabled"
-: "Aktivirt"
+: "Aktiviert"
 
 , "Unknown status ({0})"
 : "Unbekannter Status ({0})"
