@@ -1313,10 +1313,10 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 : "Die E-Mail-Adresse wurde verkürzt:"
 
 , "Every %s day"
-: "Jeden %s. Tag"
+: "Jeden %s Tag"
 
 , "Every %s week on"
-: "Jede %s. Woche am"
+: "Jede %s Woche am"
 
 , "Weekly on"
 : "Wöchentlich am"
@@ -1771,6 +1771,48 @@ Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
 , "Set event status"
 : "Terminstatus setzen"
 
+, "Notifications are enabled"
+: "Benachrichtigungen werden nicht unterdrückt"
+
+, "Notifications are disabled"
+: "Benachrichtigungen werden unterdrückt"
+
+, "Send Notification?"
+: "Benachrichtigung senden?"
+
+, "Changes to this event might send notifications."
+: "Änderungen an diesem Termin könnten Benachrichtigungen verschicken."
+
+, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: "Änderungen an diesem Termin können Benachrichtigungen senden. Drücken Sie die Taste \"Benachrichtigung werden nicht unterdrückt\", um zu \"Benachrichtigung werden unterdrückt\" zu wechseln."
+
+, "Color by Calendar"
+: "Farbe nach Kalender"
+
+, "Update Status for all Attendee?"
+: "Status für alle Teilnehmer ändern?"
+
+, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
+: "Sie sind dabei, den Gesamtterminstatus (nicht nur Ihren eigenen) zu ändern. Wollen sie wirklich den Status für alle Teilnehmer ändern?"
+
+, "Calendars to export"
+: "Zu exportierende Kalender"
+
+, "Export target"
+: "Exportziel"
+
+, "Side bar color"
+: "Farbe der Seitenleiste"
+
+, "Colors by response"
+: "Farbe nach Teilnehmerstatus"
+
+, "Colors by tags"
+: "Farbe nach Tags"
+
+, "Colors by attendee"
+: "Farbe nach Teilnehmern"
+
 , "Calendar"
 : "Kalender"
 
