@@ -520,9 +520,23 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "send notification"
 : "Versendet Benachrichtigungen"
 
+, "send notification to all access container"
+: "Versendet Benachrichtigungen an alle, die Zugriff auf den Container haben"
+
 , "controls sending notification of Leads"
 : "Steuert das versenden von Benachrichtigungen für Leads"
 
+, "Send Notification?"
+: "Benachrichtigung senden?"
+
+, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
+: "Änderungen an diesem Lead können Benachrichtigungen senden. Drücken Sie die Taste \"Benachrichtigung werden nicht unterdrückt\", um zu \"Benachrichtigung werden unterdrückt\" zu wechseln."
+
+, "Notifications are enabled"
+: "Benachrichtigungen werden nicht unterdrückt"
+
+, "Notifications are disabled"
+: "Benachrichtigungen werden unterdrückt"
 , "Lead"
 : "Lead"
 
