@@ -514,6 +514,11 @@ Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
 , "controls sending notification of Leads"
 : "controls sending notification of Leads"
 
+, "Your are sure, that some changes can send a notification?"
+: "Your are sure, that some changes can send a notification?"
+
+, "Mute Notification"
+: "Mute Notification"
 , "Lead"
 : "Lead"
 
