@@ -1321,6 +1321,96 @@ Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
 , "Redirects to external email domains are not allowed."
 : "Weiterleitungen zu externen E-Mail-Konten sind nicht erlaubt."
 
+, "It is not allowed to copy e-mails in the same account."
+: "E-Mails innerhalb eines Kontos zu kopieren ist nicht erlaubt."
+
+, "Copy"
+: "Kopieren"
+
+, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
+: "Diese Nachricht ist möglicherweise SPAM. Bitte helfen Sie, das Anti-SPAM-System mit Ihrer Entscheidung zu trainieren: \"Ja, es ist SPAM\" oder \"Nein, kein SPAM\""
+
+, "Yes, it is SPAM"
+: "Ja, es ist SPAM"
+
+, "No, it is not"
+: "Nein, kein SPAM"
+
+, "It is SPAM"
+: "Es ist SPAM"
+
+, "It is not SPAM"
+: "Kein SPAM"
+
+, "Confirm SPAM Suspicion"
+: "SPAM Verdacht bestätigen"
+
+, "This message might be SPAM"
+: "Bei dieser Nachricht könnte es sich um SPAM handeln"
+
+, "GENDER_Message"
+: "female"
+
+, "Test IMAP Connection"
+: "IMAP-Verbindung testen"
+
+, "Test SMTP Connection"
+: "SMTP-Verbindung testen"
+
+, "Server connection failed. Do you still want to save this setting and exit?"
+: "Server-Verbindung fehlgeschlagen. Möchten Sie die Einstellungen trotzdem speichern?"
+
+, "Connection succeed"
+: "Verbindung erfolgreich"
+
+, "Connection failed"
+: "Verbindung fehlgeschlagen"
+
+, "{server} Connection Status"
+: "{server} Verbindungsstatus"
+
+, "Credentials missing"
+: "Zugangsdaten fehlen"
+
+, "Hostname missing"
+: "Hostname fehlt"
+
+, "Connecting to {0} server..."
+: "Verbindung zu {0} Server wird aufgebaut..."
+
+, "It is not possible to convert the account to this type."
+: "Es ist nicht möglich, das Konto in diesen Typ umzuwandeln."
+
+, "Dear user,"
+: "Lieber Benutzer,"
+
+, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
+: "%1$s ist aufgefallen, dass die eingerichtete Daten-Syncronisation auf Ihrem Gerät nicht mehr aktiv arbeitet. Bitte starten Sie die Syncronisation auf Ihrem Gerät noch einmal neu."
+
+, "Thank you."
+: "Besten Dank."
+
+, "Your %1$s Team"
+: "Ihr %1$s Team"
+
+, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
+: "Massen-Mails werden nicht an die eingetragenen CC und/oder BCC Empfänger geschickt. Bitte entfernen Sie diese."
+
+, "Internal user accounts need a valid user"
+: "Das persönliche Systemkonto benötigt einen validen Benutzer"
+
+, "IMAP Credentials missing"
+: "IMAP Zugangsdaten fehlen"
+
+, "SMTP Credentials missing"
+: "SMTP Zugangsdaten fehlen"
+
+, "IMAP Hostname missing"
+: "IMAP Hostname fehlt"
+
+, "SMTP Hostname missing"
+: "SMTP Hostname fehlt"
+
 , "Signature"
 : "Signatur"
 
